pub struct PrepareFightEntityPower {
pub entity_id: Option<String>,
pub power: Option<f64>,
}Fields
entity_id: Option<String>power: Option<f64>Trait Implementations
Sourceimpl Clone for PrepareFightEntityPower
impl Clone for PrepareFightEntityPower
Sourcefn clone(&self) -> PrepareFightEntityPower
fn clone(&self) -> PrepareFightEntityPower
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareFightEntityPower
impl Debug for PrepareFightEntityPower
Sourceimpl Default for PrepareFightEntityPower
impl Default for PrepareFightEntityPower
Sourcefn default() -> PrepareFightEntityPower
fn default() -> PrepareFightEntityPower
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PrepareFightEntityPower
impl<'de> Deserialize<'de> for PrepareFightEntityPower
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PrepareFightEntityPower
impl JsonSchema for PrepareFightEntityPower
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PrepareFightEntityPower
impl PartialEq for PrepareFightEntityPower
Sourceimpl Serialize for PrepareFightEntityPower
impl Serialize for PrepareFightEntityPower
Sourceimpl Tsify for PrepareFightEntityPower
impl Tsify for PrepareFightEntityPower
const DECL: &'static str = "export interface PrepareFightEntityPower {\n entity_id?: string | null;\n power?: number | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for PrepareFightEntityPower