pub struct PrepareFightSpawn {
pub entity_id: String,
pub delay: Option<f64>,
pub position: Option<Coordinates>,
}Fields
entity_id: Stringdelay: Option<f64>position: Option<Coordinates>Trait Implementations
Sourceimpl Clone for PrepareFightSpawn
impl Clone for PrepareFightSpawn
Sourcefn clone(&self) -> PrepareFightSpawn
fn clone(&self) -> PrepareFightSpawn
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareFightSpawn
impl Debug for PrepareFightSpawn
Sourceimpl Default for PrepareFightSpawn
impl Default for PrepareFightSpawn
Sourcefn default() -> PrepareFightSpawn
fn default() -> PrepareFightSpawn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PrepareFightSpawn
impl<'de> Deserialize<'de> for PrepareFightSpawn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PrepareFightSpawn
impl JsonSchema for PrepareFightSpawn
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PrepareFightSpawn
impl PartialEq for PrepareFightSpawn
Sourceimpl Serialize for PrepareFightSpawn
impl Serialize for PrepareFightSpawn
Sourceimpl Tsify for PrepareFightSpawn
impl Tsify for PrepareFightSpawn
const DECL: &'static str = "export interface PrepareFightSpawn {\n entity_id: string;\n delay?: number | null;\n position?: Coordinates | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for PrepareFightSpawn